==> ulyxex.0.0.4.with-tinyMce.zip: pages/code/admin_home.php <==
<?php
class Site extends Admin {
	public function site_params() {
		$h = New Html();
		if ($_SESSION['level'] == 1) {
			$req = 	"SELECT ".PARAMS.".*,".PAGES.".NAME FROM ".PARAMS.",".PAGES.
					" WHERE ".PARAMS.".ID = 1 AND ".PAGES.".ID = ".PARAMS.".PAGEID";
			$req = $this->req($req);
			$dat = mysql_fetch_assoc($req);
			$content = $h->input("hidden","paramId",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$content .= $h->p(" page name in use for home is \"".$h->b($dat['NAME'])."\"");
			$content .= $h->p(" select home page ".$this->list_pages_select($dat['PAGEID'],"catId"));
			$content .= $h->p(" select sandbox page ".$this->list_pages_select($dat['SANDBOXID'],"sandBoxId") );
			$content .= $h->p(" website administrator mail ".$h->input("text","mail",$dat['MAIL']));
			$content .= $h->p($h->input("submit","save","save all"));
			$form = $content;
			$result = $h->form($form,"page","post","admin.php?action=admin_home");
			return $result;
		}
	}
	public function update_site_params() {
		$h = New Html();
		$req = "UPDATE ".PARAMS." SET PAGEID = '".$_POST['catId'].
		"',MAIL = '".$h->safe($_POST['mail']).
		"',SANDBOXID = '".$h->num($_POST['sandBoxId'])."' WHERE ID = 1";
		$req = $this->req($req);
		$req = "UPDATE ".PAGES." SET HIDE = 1 "." WHERE ID = ".$h->num($_POST['sandBoxId']);
		$req = $this->req($req);
		$result = $h->h3("params updated !");
		return $result;
	}
	public function list_pages_select($catId,$name) {
		$h = New Html();
		$req = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$req = $this->req($req);
		$elements = array();
		while ( $line = mysql_fetch_assoc($req) ) {
			if ($line['ID'] == $catId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $h->select($elements,$name,$catId);
		return $result;
	}
}
?>

==> ulyxex.0.0.5.with-tinyMce.zip: pages/code/admin_home.php <==
<?php
class Site extends Admin {
	public function site_params() {
		$h = New Html();
		if ($_SESSION['level'] == 1) {
			$query = 	"SELECT ".PARAMS.".*,".PAGES.".NAME FROM ".PARAMS.",".PAGES.
					" WHERE ".PARAMS.".ID = 1 AND ".PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = mysql_fetch_assoc($query);
			$content = $h->input("hidden","paramId",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$content .= $h->p(" page name in use for home is \"".$h->b($dat['NAME'])."\"");
			$content .= $h->p(" select home page ".$this->list_pages_select($dat['PAGEID'],"catId"));
			// $content .= $h->p(" select sandbox page ".$this->list_pages_select($dat['SANDBOXID'],"sandBoxId") );
			$content .= $h->p(" website administrator mail ".$h->input("text","mail",$dat['MAIL']));
			$content .= $h->p($h->input("submit","save","save all"));
			$form = $content;
			$result = $h->form($form,"page","post","admin.php?action=admin_home");
			return $result;
		}
	}
	public function update_site_params() {
		$h = New Html();
		$query = "UPDATE ".PARAMS." SET PAGEID = '".$_POST['catId'].
		"',MAIL = '".$h->safe($_POST['mail']).
		"',SANDBOXID = '".$h->num($_POST['sandBoxId'])."' WHERE ID = 1";
		$query = $this->q($query);
		$query = "UPDATE ".PAGES." SET HIDE = 1 "." WHERE ID = ".$h->num($_POST['sandBoxId']);
		$query = $this->q($query);
		$result = $h->h3("params updated !");
		return $result;
	}
	public function list_pages_select($catId,$name) {
		$h = New Html();
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $catId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $h->select($elements,$name,$catId);
		return $result;
	}
}
?>
